@@ -62,6 +62,7 @@ class Connection(ABC):
     async def _connection_lost_callback(self) -> None:
         """Callback to resume the connection on connection lost."""
         if self._reconnect_on_failure and not self._closing:
+            _LOGGER.error("Connection to device lost. Trying to reconnect")
             await self._reconnect()
 
     async def _connect(self) -> None:
@@ -101,8 +102,7 @@ class Connection(ABC):
     async def close(self) -> None:
         """Close the connection."""
         self._closing = True
-        if self.protocol is not None:
-            await self.protocol.shutdown()
+        await self.protocol.shutdown()
 
     @property
     def protocol(self) -> Protocol:
