@@ -1,7 +1,7 @@
 """Contains frame class."""
 from __future__ import annotations
 
-from abc import ABC
+from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
 from enum import IntEnum
 from typing import ClassVar, Dict, Final, List, Optional
@@ -36,9 +36,12 @@ class RequestTypes(IntEnum):
     BOILER_CONTROL = 0x3B
     PROGRAM_VERSION = 0x40
     DATA_SCHEMA = 0x55
+    ALERTS = 0x3D
 
 
-REQUEST_TYPES = {x.value: f"requests.{util.to_camelcase(x.name)}" for x in RequestTypes}
+REQUEST_TYPES = {
+    x.value: f"requests.{util.to_camelcase(x.name)}Request" for x in RequestTypes
+}
 
 
 class ResponseTypes(IntEnum):
@@ -54,10 +57,11 @@ class ResponseTypes(IntEnum):
     BOILER_CONTROL = 0xBB
     PROGRAM_VERSION = 0xC0
     DATA_SCHEMA = 0xD5
+    ALERTS = 0xBD
 
 
 RESPONSE_TYPES = {
-    x.value: f"responses.{util.to_camelcase(x.name)}" for x in ResponseTypes
+    x.value: f"responses.{util.to_camelcase(x.name)}Response" for x in ResponseTypes
 }
 
 
@@ -68,7 +72,9 @@ class MessageTypes(IntEnum):
     SENSOR_DATA = 0x35
 
 
-MESSAGE_TYPES = {x.value: f"messages.{util.to_camelcase(x.name)}" for x in MessageTypes}
+MESSAGE_TYPES = {
+    x.value: f"messages.{util.to_camelcase(x.name)}Message" for x in MessageTypes
+}
 
 
 # Dictionary of frame handler classes indexed by frame types.
@@ -84,8 +90,8 @@ def get_frame_handler(frame_type: int) -> str:
 
 
 @dataclass
-class Frame(ABC):
-    """Represents base frame class."""
+class FrameDataClass:
+    """Data class mixin for the frame."""
 
     recipient: int = BROADCAST_ADDRESS
     sender: int = ECONET_ADDRESS
@@ -93,14 +99,23 @@ class Frame(ABC):
     econet_version: int = ECONET_VERSION
     message: MessageType = field(default_factory=bytearray)
     data: DeviceDataType = field(default_factory=dict)
+
+
+class Frame(ABC, FrameDataClass):
+    """Represents base frame class."""
+
     frame_type: ClassVar[int]
 
-    def __post_init__(self) -> None:
+    def __init__(self, *args, **kwargs):
         """Process frame message and data."""
+        super().__init__(*args, **kwargs)
+
         if not self.message:
+            # If message not set, create message bytes from data.
             self.message = self.create_message(self.data)
 
         if self.message and not self.data:
+            # If message is set and data is not, decode message.
             self.data = self.decode_message(self.message)
 
     def __len__(self) -> int:
@@ -111,13 +126,13 @@ class Frame(ABC):
         """Check if frame is instance of type."""
         return any(self.frame_type == x for x in args)
 
+    @abstractmethod
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
-        return bytearray()
 
+    @abstractmethod
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
-        return {}
 
     @property
     def length(self) -> int:
@@ -166,6 +181,14 @@ class Frame(ABC):
 class Request(Frame):
     """Represents request frame."""
 
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        return bytearray()
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        return {}
+
     def response(self, **args) -> Optional[Response]:
         """Return response object for current request."""
         return None
@@ -174,6 +197,14 @@ class Request(Frame):
 class Response(Frame):
     """Represents response frame."""
 
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        return bytearray()
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        return {}
+
 
 class Message(Response):
     """Represents message frame."""
